==> haskell-yesod-1.4.4-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.4.4
id: yesod-1.4.4-1DySBQUMfKs6MhbOHp5gwm
key: yesod-1.4.4-1DySBQUMfKs6MhbOHp5gwm
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2 Yesod.Default.Main
    Yesod.Default.Util Yesod.Default.Handlers
abi: bcc9d0fc1c971df31ac009d7531f7a1b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-1.4.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-1.4.4
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-1.4.4
hs-libraries: HSyesod-1.4.4-1DySBQUMfKs6MhbOHp5gwm
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx base-4.9.0.0
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    conduit-extra-1.1.15-9BEhw2PHvUTFj1lUJfHKAK
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu directory-1.2.6.2
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.2-JTAIQ2hISya9krzRihq4vG
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    shakespeare-2.0.12.1-5TO0z9PSLt7EPkCrYoKv4I
    streaming-commons-0.1.17-JBMCKUjr3AjHIyRG4GSmU7
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    transformers-0.5.2.0 unix-2.7.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    wai-3.2.1.1-G3x7tNXaUUGBY6K4SzJOAN
    wai-extra-3.0.19.1-4SJaVBBlorXCVw8g8Jytas
    wai-logger-2.3.0-EZQMUMTGcl9LAjZygwoAoH
    warp-3.2.11.1-a2JA9SFJiHKEK34ooMk5x
    yaml-0.8.22-INeHbn75CrTI4wcMhFaML4
    yesod-core-1.4.32-CcMo4eC5B13DfXXmXm4BDa
    yesod-form-1.4.11-IGQ3G8uAtBh8VfBnSxGY3d
    yesod-persistent-1.4.1.1-6pOXGN9bxfa3i3vQHMf9F8
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-1.4.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.4.5
id: yesod-1.4.5-8zrBq76E0zQ5QV6dg6iL9A
key: yesod-1.4.5-8zrBq76E0zQ5QV6dg6iL9A
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2 Yesod.Default.Main
    Yesod.Default.Util Yesod.Default.Handlers
abi: 7a042b9c2d98bf07494e1e86f9e0812b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-1.4.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-1.4.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-1.4.5
hs-libraries: HSyesod-1.4.5-8zrBq76E0zQ5QV6dg6iL9A
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx base-4.9.0.0
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    conduit-extra-1.1.15-9BEhw2PHvUTFj1lUJfHKAK
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu directory-1.2.6.2
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.2-JTAIQ2hISya9krzRihq4vG
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    shakespeare-2.0.12.1-5TO0z9PSLt7EPkCrYoKv4I
    streaming-commons-0.1.17-JBMCKUjr3AjHIyRG4GSmU7
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    transformers-0.5.2.0 unix-2.7.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    wai-3.2.1.1-G3x7tNXaUUGBY6K4SzJOAN
    wai-extra-3.0.19.1-4SJaVBBlorXCVw8g8Jytas
    wai-logger-2.3.0-EZQMUMTGcl9LAjZygwoAoH
    warp-3.2.11.1-a2JA9SFJiHKEK34ooMk5x
    yaml-0.8.22-INeHbn75CrTI4wcMhFaML4
    yesod-core-1.4.32-CcMo4eC5B13DfXXmXm4BDa
    yesod-form-1.4.11-IGQ3G8uAtBh8VfBnSxGY3d
    yesod-persistent-1.4.1.1-6pOXGN9bxfa3i3vQHMf9F8
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
